"use strict";

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { getRNStylesFromShikiStyle } from '../../utils/style-transformer';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const baseStyles = StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  codeContainer: {
    padding: 16,
    minWidth: '100%'
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  token: {
    fontFamily: monospaceFont,
    fontSize: 14
  }
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const themeStyles = useMemo(() => getRNStylesFromShikiStyle(theme), [theme]);
  const renderToken = (token, rowIndex, tokenIndex) => {
    const tokenStyle = {
      color: token.color || themeStyles.editor?.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal'
    };
    return /*#__PURE__*/_jsx(Text, {
      style: [baseStyles.token, tokenStyle, textStyle, {
        fontSize
      }],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [baseStyles.scrollView, themeStyles.editor, scrollViewProps?.style],
    contentContainerStyle: [baseStyles.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: baseStyles.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map